# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: external_tool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'external_tool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65xternal_tool_service.proto\x12\x07gateway\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xd4\x01\n\x13\x45xternalToolRequest\x12\x30\n\x0creq_datetime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttool_name\x18\x02 \x01(\t\x12\x38\n\x06params\x18\x03 \x03(\x0b\x32(.gateway.ExternalToolRequest.ParamsEntry\x12\x0f\n\x07payload\x18\x04 \x03(\x0c\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x11\x45xternalToolReply\x12(\n\x07results\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2l\n\x13\x45xternalToolService\x12U\n\x19HandleExternalToolRequest\x12\x1c.gateway.ExternalToolRequest\x1a\x1a.gateway.ExternalToolReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'external_tool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXTERNALTOOLREQUEST_PARAMSENTRY']._loaded_options = None
  _globals['_EXTERNALTOOLREQUEST_PARAMSENTRY']._serialized_options = b'8\001'
  _globals['_EXTERNALTOOLREQUEST']._serialized_start=104
  _globals['_EXTERNALTOOLREQUEST']._serialized_end=316
  _globals['_EXTERNALTOOLREQUEST_PARAMSENTRY']._serialized_start=271
  _globals['_EXTERNALTOOLREQUEST_PARAMSENTRY']._serialized_end=316
  _globals['_EXTERNALTOOLREPLY']._serialized_start=318
  _globals['_EXTERNALTOOLREPLY']._serialized_end=379
  _globals['_EXTERNALTOOLSERVICE']._serialized_start=381
  _globals['_EXTERNALTOOLSERVICE']._serialized_end=489
# @@protoc_insertion_point(module_scope)
